package de.intevation.flys.importer;

import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import org.apache.log4j.Logger;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.exception.ConstraintViolationException;

import de.intevation.flys.model.MorphologicalWidth;
import de.intevation.flys.model.River;


public class ImportMorphWidth {

    private static Logger log = Logger.getLogger(ImportMorphWidth.class);

    protected MorphologicalWidth peer;

    protected ImportUnit unit;

    protected List<ImportMorphWidthValue> values;

    public ImportMorphWidth() {
        this.values = new ArrayList<ImportMorphWidthValue>();
    }

    public void addValue(ImportMorphWidthValue value) {
        this.values.add(value);
    }

    public void setUnit(ImportUnit unit) {
        this.unit = unit;
    }

    public void storeDependencies(River river) {
        log.info("store dependencies");

        MorphologicalWidth peer = getPeer(river);

        if (peer != null) {
            log.info("store morphological width values");

            for (ImportMorphWidthValue value : values) {
                value.storeDependencies(peer);
            }
        }
    }

    public MorphologicalWidth getPeer(River river) {
        log.info("get peer");

        if (peer == null) {
            Session session = ImporterSession.getInstance()
                .getDatabaseSession();

            Query query = session.createQuery("from MorphologicalWidth where "
                + "   river=:river and " + "   unit=:unit");

            query.setParameter("river", river);
            query.setParameter("unit", unit.getPeer());

            List<MorphologicalWidth> widths = query.list();

            if (widths.isEmpty()) {
                log.debug("Create new MorphologicalWidth DB instance.");

                peer = new MorphologicalWidth(river, unit.getPeer());

                session.save(peer);
            }
            else {
                peer = widths.get(0);
            }
        }

        return peer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
